package com.ruoyi.system.mapper.projectV2;

import com.ruoyi.system.domain.projectV2.XmConstructionRate;

import java.util.List;

/**
 * 项目施工进度Mapper接口
 * 
 * @author boman
 * @date 2023-02-23
 */
public interface XmConstructionRateMapper 
{
    /**
     * 查询项目施工进度
     * 
     * @param id 项目施工进度ID
     * @return 项目施工进度
     */
    public XmConstructionRate selectXmConstructionRateById(Long id);

    /**
     * 查询项目施工进度列表
     * 
     * @param xmConstructionRate 项目施工进度
     * @return 项目施工进度集合
     */
    public List<XmConstructionRate> selectXmConstructionRateList(XmConstructionRate xmConstructionRate);

    /**
     * 新增项目施工进度
     * 
     * @param xmConstructionRate 项目施工进度
     * @return 结果
     */
    public int insertXmConstructionRate(XmConstructionRate xmConstructionRate);

    /**
     * 修改项目施工进度
     * 
     * @param xmConstructionRate 项目施工进度
     * @return 结果
     */
    public int updateXmConstructionRate(XmConstructionRate xmConstructionRate);

    /**
     * 删除项目施工进度
     * 
     * @param id 项目施工进度ID
     * @return 结果
     */
    public int deleteXmConstructionRateById(Long id);

    /**
     * 批量删除项目施工进度
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteXmConstructionRateByIds(Long[] ids);
}
